##  Creating a Dashboard
You can create new dashboards to facilitate stakeholder management and showcase key deliverables and objectives specific to major initiatives.
To create a new dashboard, follow these steps:
  1. On the dashboard page, click New Dashboard.
  2. On the page that appears, enter a name for the dashboard and select how you want to proceed: create an empty dashboard from scratch or copy an existing dashboard and then customize it to your needs. Selecting an existing dashboard as a template allows you to create new dashboards with less effort, making it easier to tailor information for different stakeholders or teams based on their roles and responsibilities.
  3. Click Create Dashboard. You land on the dashboard editing page.
  4. To add panels to the dashboard, drag and drop them from the right-side panel to the dashboard grid. If prompted, configure the panel by providing a title and selecting the elements to include, then click Save. You can include reports, diagrams, fact sheet charts, KPI panels, and more.
**Tip**
For optimal performance and to prevent potential slowdowns, it's recommended to limit the number of panels added to dashboards, particularly those containing large volumes of data, such as saved searches. Try to avoid adding more than 30–40 panels to a dashboard for the best user experience and system performance.
  5. Adjust the dashboard layout. You can move, resize, duplicate, and delete panels.
To resize a panel, hover over the panel border until the cursor transforms into a double-sided arrow, click and hold the border, then drag it to achieve the panel size that you need. You can also use keyboard shortcuts to resize panels and perform other actions. To learn more, see [Keyboard Navigation and Shortcuts](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759aa5c7a4410149e39ce8eb3d5075f__keyboard_navigation_and_shortcuts).
You can apply the global filter to the dashboard to filter contents in all panels. To learn more, see [Global Filtering in Dashboards](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759aa5c7a4410149e39ce8eb3d5075f__global_filtering_in_dashboards).
  6. Click Save.
![Resizing and Moving Dashboard Panels](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757cf207a44101482538cc34251e631_LowRes.gif)
Resizing and Moving Dashboard Panels
